# PriceFormatProductRatePlanChargeTier

Indicates if pricing is a flat fee or is per unit. This field is for tiered and volume pricing models only. 

## Enum

* `FLAT_FEE` (value: `'Flat Fee'`)

* `PER_UNIT` (value: `'Per Unit'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


